@@ -1,6 +1,6 @@
 package Bread::Board::Declare::Meta::Role::Class;
 BEGIN {
-  $Bread::Board::Declare::Meta::Role::Class::VERSION = '0.01';
+  $Bread::Board::Declare::Meta::Role::Class::VERSION = '0.02';
 }
 use Moose::Role;
 # ABSTRACT: class metarole for Bread::Board::Declare
@@ -46,7 +46,7 @@ Bread::Board::Declare::Meta::Role::Class - class metarole for Bread::Board::Decl
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -61,11 +61,13 @@ Returns all of the services that are associated with attributes in this class.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
 =over 4
 
 =item *
 
-L<Bread::Board::Declare>
+L<Bread::Board::Declare|Bread::Board::Declare>
 
 =back
 
