@@ -1,6 +1,6 @@
 package Bread::Board::Declare::Role::Object;
 BEGIN {
-  $Bread::Board::Declare::Role::Object::VERSION = '0.01';
+  $Bread::Board::Declare::Role::Object::VERSION = '0.02';
 }
 use Moose::Role;
 
@@ -48,17 +48,19 @@ Bread::Board::Declare::Role::Object
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =for Pod::Coverage BUILD
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
 =over 4
 
 =item *
 
-L<Bread::Board::Declare>
+L<Bread::Board::Declare|Bread::Board::Declare>
 
 =back
 
